@@ -12,7 +12,7 @@ use List::Util qw(any);
 use Scalar::Util qw(blessed);
 use Kelp::Context;
 
-our $VERSION = '2.12';
+our $VERSION = '2.13';
 
 # Basic attributes
 attr -host => hostname;
@@ -52,20 +52,20 @@ sub new
 {
     my $self = shift->SUPER::new(@_);
 
-    Kelp::Base::_DEBUG(1 => 'Loading essential modules...');
+    Kelp::Util::_DEBUG(1 => 'Loading essential modules...');
 
     # Always load these modules, but allow client to override
     $self->_load_config();
     $self->_load_routes();
 
-    Kelp::Base::_DEBUG(1 => 'Loading modules from config...');
+    Kelp::Util::_DEBUG(1 => 'Loading modules from config...');
 
     # Load the modules from the config
     if (defined(my $modules = $self->config('modules'))) {
         $self->load_module($_) for (@$modules);
     }
 
-    Kelp::Base::_DEBUG(1 => 'Calling build method...');
+    Kelp::Util::_DEBUG(1 => 'Calling build method...');
 
     $self->build();
     return $self;
@@ -112,7 +112,7 @@ sub _load_config
     my $self = shift;
     $self->load_module($self->config_module, extra => $self->__config);
 
-    Kelp::Base::_DEBUG(config => 'Merged configuration: ', $self->config_hash);
+    Kelp::Util::_DEBUG(config => 'Merged configuration: ', $self->config_hash);
 }
 
 sub _load_routes
@@ -155,7 +155,7 @@ sub load_module
         $args_from_config = $self->config("modules_init.$name") // {};
     }
 
-    Kelp::Base::_DEBUG(modules => "Loading $class module with args: ", {%$args_from_config, %args});
+    Kelp::Util::_DEBUG(modules => "Loading $class module with args: ", {%$args_from_config, %args});
 
     $module->build(%$args_from_config, %args);
     return $module;
@@ -214,7 +214,7 @@ sub run
     my $self = shift;
     my $app = sub { $self->psgi(@_) };
 
-    Kelp::Base::_DEBUG(1 => 'Running the application...');
+    Kelp::Util::_DEBUG(1 => 'Running the application...');
 
     # Add middleware
     if (defined(my $middleware = $self->config('middleware'))) {
@@ -228,7 +228,7 @@ sub run
             my $mw = Plack::Util::load_class($class, 'Plack::Middleware');
             my $args = $self->config("middleware_init.$class") // {};
 
-            Kelp::Base::_DEBUG(modules => "Wrapping app in $mw middleware with args: ", $args);
+            Kelp::Util::_DEBUG(modules => "Wrapping app in $mw middleware with args: ", $args);
 
             $app = $mw->wrap($app, %$args);
         }
